@@ -1,4 +1,4 @@
-from libplasma.src.dataset import Dataset
+from libplasma.src.dataset import *
 from libplasma.src.utils import *
 
 setup_plasma_directory()
